@@ -104,6 +104,11 @@ void BayonneSession::initialize(void)
 	setSid();
 }
 
+bool BayonneSession::setFeeder(BayonneFeeder *feeder)
+{
+	return false;
+}
+
 void BayonneSession::detach(void)
 {
 	exittimer = 0;
@@ -134,6 +139,7 @@ void BayonneSession::initialevent(void)
 	Event event;
 
 	event.id = ENTER_STATE;
+	event.name = "initial";
 	event.timeslot = timeslot;
 	putEvent(&event);
 }
@@ -293,6 +299,7 @@ const char *BayonneSession::getExternal(const char *id)
 	time_t now;
 
 	const char *p = strchr(id, '.');
+	char *tmp;
 
 	if(!p || ((p - id) < 6))
 		return NULL;
@@ -302,6 +309,22 @@ const char *BayonneSession::getExternal(const char *id)
 		id += 8;
 		if(!stricmp(id, "gid") || !stricmp(id, "id") || !stricmp(id, "sid"))
 			return var_sid;
+		else if(!stricmp(id, "uid"))
+		{
+			tmp = getTemp();
+			time(&now);
+			snprintf(tmp, 16, "%08x-%04x", now, timeslot); 
+			return tmp;
+		}			
+		else if(!stricmp(id, "mid"))
+		{
+			tmp = getTemp();
+			time(&now);
+			snprintf(tmp, 24, "%08x-%04x.%s", now, timeslot, audio.libext);
+			return tmp;
+		}		
+		else if(!stricmp(id, "libext"))
+			return audio.libext;	
 		else if(!stricmp(id, "line"))
 		{
 			if(holding)
@@ -547,6 +570,7 @@ retry:
 
 		stopTimer();
 		event->id = ENTER_STATE;
+		event->name = state.name;
 		goto retry;
 	}
 
