@@ -769,10 +769,13 @@ void BayonneTSession::sysHeader(const char *tsid)
                 snprintf(buf, sizeof(buf), "CTYPE: %s\n", 
                         getExternal("session.type"));
 		libWrite(buf);
-		cp = getSymbol("session.auth");
+		cp = getSymbol("session.info");
 		if(!cp)
 			cp = "none";
-		snprintf(buf, sizeof(buf), "CAUTH: %s\n", cp);
+		snprintf(buf, sizeof(buf), "CINFO: %s\n", cp);
+		libWrite(buf);
+		cp = getSymbol("session.callref");
+		snprintf(buf, sizeof(buf), "CREF: %s\n", cp);
 		libWrite(buf);
 		libWrite("\n");
 
