@@ -20,6 +20,7 @@
 #include <ccrtp/rtp.h>
 #undef	HAVE_CONFIG_H
 #ifdef	HAVE_EXOSIP2
+#include <osip2/osip_mt.h> 
 #include <eXosip2/eXosip.h>
 #else
 #include <eXosip/eXosip.h>
@@ -36,12 +37,14 @@ class Registry : public ScriptRegistry
 public:
 	const char *uri, *contact, *proxy;
 	const char *iface;
+//	const char *route;
 	const char *hostid;
 	const char *portid;
 	const char *userid;
 	const char *secret;
 	const char *type;
 	const char *realm;
+	const char *dtmf;
 	int regid;
 	bool active;
 };
@@ -164,6 +167,10 @@ protected:
 	bool peerAudio(Encoded encoded);
 	void postAudio(Encoded encoded);
 
+	void sendDTMFInfo(char digit, unsigned timeout = 160);
+
+	void setDTMFMode(const char *mode);
+
 public:
 	Session(timeslot_t ts);
 	~Session();
