@@ -22,6 +22,23 @@ namespace server {
 using namespace ost;
 using namespace std;
 
+const char *Checks::chkBGM(Line *line, ScriptImage *img)
+{
+	if(getMember(line))
+		return "bgm has no members";
+
+	if(hasKeywords(line))
+		return "bgm uses no keywords";
+
+	if(line->argc > 1)
+		return "bgm has only one argument";
+
+	if(!line->argc)
+		return "bgm feed argument is missing";
+
+	return NULL;
+}
+
 const char *Checks::chkConfig(Line *line, ScriptImage *img)
 {
 	Name *scr = img->getCurrent();
