@@ -22,6 +22,35 @@ namespace server {
 using namespace ost;
 using namespace std;
 
+bool Methods::scrBGM(void)
+{
+	const char *bgm = getValue(NULL);
+	BayonneFeeder *feed;
+
+	if(!stricmp(bgm, "off") || !stricmp(bgm, "none") || !*bgm)
+	{
+		setFeeder(NULL);
+		advance();
+		return true;
+	}
+
+	feed = BayonneFeeder::get(bgm);
+	if(!feed)
+	{
+		error("bgm-invalid");
+		return true;
+	}
+
+	if(!setFeeder(feed))
+	{
+		error("bgm-unsupported");
+		return true;
+	}
+
+	advance();
+	return true;
+}
+
 bool Methods::scrTransfer(void)
 {
 	char nbuf[MAX_PATHNAME];
@@ -108,6 +137,8 @@ bool Methods::scrDTMF(void)
 	if(audio.tone)
 		delete audio.tone;
 
+	state.tone.syncdigit = state.tone.digits;
+	state.tone.synctimer = interdigit * 2;
 	state.tone.exiting = false;
 	state.tone.digits[0] = 0;
 	while(len < 64 && NULL != (cp = getValue(NULL)))
@@ -117,7 +148,7 @@ bool Methods::scrDTMF(void)
 	}
 
 	audio.tone = new DTMFTones(state.tone.digits, level, getToneFraming(), interdigit);	
-	setState(STATE_TONE);
+	setState(STATE_DTMF);
 	return false;
 }
 
