@@ -148,6 +148,7 @@ class Runtime : public ScriptRuntime, public Bayonne
 protected:
         unsigned long getTrapMask(const char *trapname);
 
+	static bool testNumber(ScriptInterp *interp, const char *v);
 	static bool testFile(ScriptInterp *interp, const char *v);
 	static bool testDir(ScriptInterp *interp, const char *v);
 	static bool testTimeslot(ScriptInterp *interp, const char *v);
@@ -177,6 +178,7 @@ public:
 class Methods : public BayonneSession
 {
 public:
+	bool scrBGM(void);
 	bool scrList(void);
 	bool scrEcho(void);
 	bool scrPickup(void);
@@ -219,6 +221,7 @@ public:
 class Checks : public ScriptChecks, public Bayonne
 {
 public:
+	const char *chkBGM(Line *line, ScriptImage *img);
 	const char *chkList(Line *line, ScriptImage *img);
 	const char *chkConfig(Line *line, ScriptImage *img);
 	const char *chkPaths(Line *line, ScriptImage *img);
